@@ -1,24 +1,16 @@
 import pytest
-from openstates.scrape.schemas.person import schema
+from openstates.scrape.schemas.bill import schema
 from openstates.scrape.base import (
     BaseModel,
     SourceMixin,
-    ContactDetailMixin,
-    LinkMixin,
     AssociatedLinkMixin,
-    OtherNameMixin,
-    IdentifierMixin,
 )
 
 
 class GenericModel(
     BaseModel,
     SourceMixin,
-    ContactDetailMixin,
-    LinkMixin,
     AssociatedLinkMixin,
-    OtherNameMixin,
-    IdentifierMixin,
 ):
     """ a generic model used for testing the base and mixins """
 
@@ -60,24 +52,6 @@ def test_add_source():
     ]
 
 
-def test_add_contact_detail():
-    m = GenericModel()
-    m.add_contact_detail(type="fax", value="111-222-3333", note="office")
-    assert m.contact_details == [
-        {"type": "fax", "value": "111-222-3333", "note": "office"}
-    ]
-
-
-def test_add_link():
-    m = GenericModel()
-    m.add_link("http://example.com/1")
-    m.add_link("http://example.com/2", note="xyz")
-    assert m.links == [
-        {"url": "http://example.com/1", "note": ""},
-        {"url": "http://example.com/2", "note": "xyz"},
-    ]
-
-
 def test_add_associated_link_match():
     m = GenericModel()
     m._add_associated_link(
@@ -152,41 +126,3 @@ def test_add_associated_link_on_duplicate_ignore():
     assert len(m._associated) == 1
     assert len(m._associated[0]["links"]) == 1
     assert m._associated[0]["note"] == "something"
-
-
-def test_add_name():
-    m = GenericModel()
-
-    m.add_name("Thiston", note="What my friends call me")
-
-    assert m.other_names == [{"name": "Thiston", "note": "What my friends call me"}]
-
-    m.add_name(
-        "Johnseph Q. Publico",
-        note="Birth name",
-        start_date="1920-01",
-        end_date="1949-12-31",
-    )
-
-    assert m.other_names == [
-        {"name": "Thiston", "note": "What my friends call me"},
-        {
-            "name": "Johnseph Q. Publico",
-            "note": "Birth name",
-            "start_date": "1920-01",
-            "end_date": "1949-12-31",
-        },
-    ]
-
-
-def test_add_identifier():
-    g = GenericModel()
-
-    with pytest.raises(TypeError):
-        g.add_identifier("id10t", foo="bar")
-
-    g.add_identifier("id10t")
-    g.add_identifier("l0l", scheme="kruft")
-
-    assert g.identifiers[-1]["scheme"] == "kruft"
-    assert g.identifiers[0]["identifier"] == "id10t"
